<?php
namespace App\Factory;
use Doctrine\DBAL\Connection;

class Branch {

  private $connection;

  public function __construct(Connection $connection) {
      $this->connection = $connection;
  }

  public function getUnits() {
    $sql = "
      SELECT DISTINCT L.CDFILIAL AS CDFILIALGRID, L.NMFILIAL,
        L.CDFILIAL || L.CDINSCMUNI AS CDFILIAL, L.CDFILIAL AS FILIAL, COUNT(*) OVER () AS limit
      FROM FILIAL L

      LEFT JOIN LOJABLOQ LO
        ON LO.CDFILIAL = L.CDFILIAL

      ORDER BY L.CDFILIAL
    ";

    $stmt = $this->connection->prepare($sql);
    $result = $stmt->executeQuery();
    return $result->fetchAllAssociative();
  }

  public function getBlockedStores($params) {
    $sql = "
      SELECT LB.CDLOJA AS CDFILIALGRID, LB.CDFILIAL||LB.CDLOJA||LB.NRDIASEMANABLOQ AS CDFILIAL,
        LO.NMLOJA, OP.NMOPERADOR, LB.CDFILIAL AS FILIAL, LB.CDLOJA AS LOJA,
        TO_CHAR(LB.DTHRBLOQUEIO, 'DD/MM/YYYY HH24:MI') AS DTHRBLOQUEIO,
        NVL(LB.NRDIASEMANABLOQ, 'T') AS NRDIASEMANABLOQ
      FROM LOJABLOQ LB
        JOIN LOJA LO
          ON LB.CDFILIAL = LO.CDFILIAL
          AND LB.CDLOJA  = LO.CDLOJA

        JOIN OPERADOR OP
          ON LB.CDOPERADOR = OP.CDOPERADOR

      WHERE LB.CDFILIAL = :CDFILIAL
        ORDER BY LB.CDLOJA
  ";

    $stmt = $this->connection->prepare($sql);
    $stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
    $result = $stmt->executeQuery();
    return $result->fetchAllAssociative();
  }

  public function getAvailableStoresByUnit($params) {
    $sql = "
      SELECT LO.CDFILIAL, LO.CDLOJA, LO.NMLOJA, LO.CDLOJA AS CDFILIALGRID
        FROM LOJA LO
      LEFT JOIN LOJABLOQ LB
        ON LB.CDFILIAL  = LO.CDFILIAL
        AND LB.CDLOJA   = LO.CDLOJA
      WHERE LO.CDFILIAL = :CDFILIAL
        AND LB.CDLOJA IS NULL
    ORDER BY LO.CDLOJA
      ";

    $stmt = $this->connection->prepare($sql);
    $stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
    $result = $stmt->executeQuery();
    return $result->fetchAllAssociative();
  }

  public function blockStores($params) {
    $sql = "
      INSERT INTO LOJABLOQ
        (CDFILIAL, CDLOJA, CDOPERADOR, DTHRBLOQUEIO, NRDIASEMANABLOQ)
      VALUES
        (:CDFILIAL, :CDLOJA, :CDOPERADOR, SYSDATE, :NRDIASEMANABLOQ)
    ";

    $stmt = $this->connection->prepare($sql);
    $stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
    $stmt->bindValue("CDLOJA", $params['CDLOJA']);
    $stmt->bindValue("CDOPERADOR", $params['CDOPERADOR']);
    $stmt->bindValue("NRDIASEMANABLOQ", $params['NRDIASEMANABLOQ']);
    return $stmt->executeQuery();
  }

  public function unlockStores($params) {
    $sql = "
      DELETE FROM LOJABLOQ
        WHERE CDFILIAL = :CDFILIAL
          AND CDLOJA   = :CDLOJA
          AND NRDIASEMANABLOQ = :NRDIASEMANABLOQ
      ";
    $stmt = $this->connection->prepare($sql);
    $stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
    $stmt->bindValue("CDLOJA", $params['CDLOJA']);
    $stmt->bindValue("NRDIASEMANABLOQ", $params['NRDIASEMANABLOQ']);
    return $stmt->executeQuery();
  }

  public function getBlockedProduct($params) {
    $sql = "
      SELECT PB.CDPRODUTO AS CDFILIALGRID, PR.NMPRODUTO, OP.NMOPERADOR, 
        TO_CHAR(PB.DTHRBLOQUEIO, 'DD/MM/YYYY HH24:MI') AS DTHRBLOQUEIO,
        NVL(PB.NRDIASEMANABLOQ, 'T') AS NRDIASEMANABLOQ
      FROM PRODBLOQVND PB
      JOIN PRODUTO PR
        ON PB.CDPRODUTO = PR.CDPRODUTO

      JOIN OPERADOR OP
        ON PB.CDOPERADOR = OP.CDOPERADOR
    
      WHERE PB.CDFILIAL = :CDFILIAL
        AND PB.CDLOJA   = :CDLOJA
    ";

    $stmt = $this->connection->prepare($sql);
    $stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
    $stmt->bindValue("CDLOJA", $params['CDFILIALGRID']);
    $result = $stmt->executeQuery();
    return $result->fetchAllAssociative();
  }

  public function getStores($params) {
    $sql = "
      SELECT
        LO.CDLOJA AS CDFILIALGRID, LO.CDFILIAL||LO.CDLOJA AS CDFILIAL,
        LO.NMLOJA
      FROM LOJA LO
        WHERE LO.CDFILIAL = :CDFILIAL
      ORDER BY LO.CDLOJA
    ";

    $stmt = $this->connection->prepare($sql);
    $stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
    $result = $stmt->executeQuery();
    return $result->fetchAllAssociative();
  }

  public function getAvailableProductsByUnit($params) {
    $sql = "
    SELECT PR.CDPRODUTO, PR.CDARVPROD, PR.NMPRODUTO,
    PR.CDPRODUTO || ' - ' || PR.NMPRODUTO AS PRODUTO
    FROM PRODUTO PR
    LEFT JOIN PRODBLOQVND PB
        ON PR.CDPRODUTO = PB.CDPRODUTO
        AND PB.CDFILIAL = :CDFILIAL
        AND PB.CDLOJA   = :CDLOJA
      WHERE PB.CDPRODUTO IS NULL
      ORDER BY PR.CDARVPROD

    ";

    $stmt = $this->connection->prepare($sql);
    $stmt->bindValue("CDLOJA", $params['CDLOJA']);
    $stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
    $result = $stmt->executeQuery();
    return $result->fetchAllAssociative();
  }

  public function blockProducts($params) {
    $sql = "
    INSERT INTO PRODBLOQVND
    (CDFILIAL, CDLOJA, CDPRODUTO, CDOPERADOR, DTHRBLOQUEIO, NRDIASEMANABLOQ)
   VALUES
    (:CDFILIAL, :CDLOJA, :CDPRODUTO, :CDOPERADOR, SYSDATE, :NRDIASEMANABLOQ)

    ";
    $stmt = $this->connection->prepare($sql);
    $stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
    $stmt->bindValue("CDLOJA", $params['CDLOJA']);
    $stmt->bindValue("CDPRODUTO", $params['CDPRODUTO']);
    $stmt->bindValue("CDOPERADOR", $params['CDOPERADOR']);
    $stmt->bindValue("NRDIASEMANABLOQ", $params['NRDIASEMANABLOQ']);
    return $stmt->executeQuery();
  }

  public function removeOtherDaysStore($params) {
    $sql = "
      DELETE FROM LOJABLOQ
        WHERE CDFILIAL = :CDFILIAL
          AND CDLOJA   = :CDLOJA
    ";

    $stmt = $this->connection->prepare($sql);
    $stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
    $stmt->bindValue("CDLOJA", $params['CDLOJA']);
    return $stmt->executeQuery();
  }

  public function unblockProducts($params) {
    $sql = "
    DELETE FROM PRODBLOQVND
    	 WHERE CDFILIAL 	   = :CDFILIAL
    	   AND CDLOJA   	   = :CDLOJA
    	   AND CDPRODUTO	   = :CDPRODUTO
    	   AND NRDIASEMANABLOQ = :NRDIASEMANABLOQ
    ";
    $stmt = $this->connection->prepare($sql);
    $stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
    $stmt->bindValue("CDLOJA", $params['CDLOJA']);
    $stmt->bindValue("CDPRODUTO", $params['CDPRODUTO']);
    $stmt->bindValue("NRDIASEMANABLOQ", $params['NRDIASEMANABLOQ']);
    return $stmt->executeQuery();
  }

  public function getStandardClient($cdFilial) {
    $sql = "
      SELECT CDCLIENTE
      FROM PARAVEND
      WHERE CDFILIAL = :CDFILIAL
    ";

    $stmt = $this->connection->prepare($sql);
    $stmt->bindValue("CDFILIAL", $cdFilial);
    $result = $stmt->executeQuery();
    return $result->fetchAssociative();
  }

  public function getTipoRec($cdFilial) {
    $sql = "
      SELECT CDTIPOCONS, CDCCUSCLIE
      FROM PARAVEND
      WHERE CDFILIAL = :CDFILIAL
    ";

    $stmt = $this->connection->prepare($sql);
    $stmt->bindValue("CDFILIAL", $cdFilial);
    $result = $stmt->executeQuery();
    return $result->fetchAllAssociative();
  }

  public function getBranchs() {
    $sql = "
      SELECT CDFILIAL || ' - ' || NMFILIAL AS FILIALSELECAO,  CDFILIAL, NMFILIAL,
      CDFILIAL || ' - ' || NMFILIAL AS FILIALSELECAO2, CDFILIAL AS CDFILIAL2, NMFILIAL AS NMFILIAL2
      FROM FILIAL
      ORDER BY CDFILIAL
    ";

    $stmt = $this->connection->prepare($sql);
    $result = $stmt->executeQuery();
    return $result->fetchAllAssociative();
  }
}
