import AccessControl from '@/helpers/AccessControl';
import type { PermissionMap } from '@/helpers/AccessControl';
import { Prop, Component } from 'vue-property-decorator';
import { ZdComponent } from '@zeedhi/vuetify';
import { Menu as MenuClass } from './common/Menu';

export type SubMenuItem = MenuItem & {
  isHeader: boolean,
};

export type MenuItem = {
  href: string,
  name: string,
  label: string,
  icon: string,
  isMainPage?: boolean,
  isActive: boolean,
  permissions: PermissionMap[],
  submenu: SubMenuItem[],
};

/**
 * DocTable component
 */
@Component
export default class Menu extends ZdComponent {
  @Prop({ type: String, default: '' }) public to!: string;

  @Prop({ type: String, default: '' }) public src!: string;

  public instance!: MenuClass;

  public instanceType: typeof MenuClass = MenuClass;

  static isActiveMenu(menu: MenuItem): boolean {
    const hasSubMenu = Array.isArray(menu.submenu) && menu.submenu.length;
    const { pathname } = window.location;
    const hasActiveSubMenu = hasSubMenu && menu.submenu.find((submenu) => submenu.href === pathname);
    const isActiveMenu = (menu.href === pathname) || !!hasActiveSubMenu || !!(pathname === '/' && menu.isMainPage);
    return isActiveMenu;
  }

  static setDefaultIsActive(menuItems: MenuItem[]) {
    menuItems.forEach((menu: MenuItem) => {
      menu.isActive = Menu.isActiveMenu(menu);
    });
  }

  static hasEnabledAccessControl() {
    return process.env.VUE_APP_ENABLED_ACCESS_PROFILE === 'YES';
  }

  static isEnabledMenu(menu: MenuItem) {
    if (!Array.isArray(menu.permissions) || !menu.permissions.length) {
      return true;
    }
    return AccessControl.isValidAccess(menu.permissions);
  }

  static hasSubMenu(menu: MenuItem) {
    return Array.isArray(menu.submenu) && menu.submenu.length;
  }

  static getMenuWithAccessControl(menuItems: MenuItem[]) {
    const filtredMenu: MenuItem[] = [];

    if (!Menu.hasEnabledAccessControl()) return menuItems;

    menuItems.forEach((menu: MenuItem) => {
      if (Menu.isEnabledMenu(menu)) {
        if (Menu.hasSubMenu(menu)) {
          menu.submenu = menu.submenu.filter((submenu: SubMenuItem) => Menu.isEnabledMenu(submenu));
          const hasEnabledSubMenu = menu.submenu.some((submenu: SubMenuItem) => !submenu.isHeader);
          if (hasEnabledSubMenu) {
            filtredMenu.push(menu);
          }
        } else {
          filtredMenu.push(menu);
        }
      }
    });
    return filtredMenu;
  }

  getMenuItems() {
    return [
      {
        name: 'dashboard',
        label: 'Início',
        icon: 'mdi-home',
        href: '/',
      },
    ] as MenuItem[];
  }
}
