export type PermissionValue = null | 'N' | 'S';

export type PermissionType = {
  IDADIANTAPEDIDOS: PermissionValue,
  IDBLOQLOJA: PermissionValue;
  IDBLOQPROD: PermissionValue;
  IDCANCELAPEDIDOS: PermissionValue;
  IDDASHBOARD: PermissionValue;
  IDREMOVELOGERRO: PermissionValue;
  IDTEMPOATRASO: PermissionValue;
};

export type PermissionMap = keyof PermissionType;

class AccessControl {
  static permission: Record<PermissionMap, PermissionValue> | null = null;

  constructor() {
    this.loadPermission();
  }

  loadPermission() {
    try {
      const encodedPermission = localStorage.getItem('PERMISSIONS') || '';
      const decodedPermission = atob(encodedPermission) || '{}';
      const parsedPermission = JSON.parse(decodedPermission);
      AccessControl.permission = parsedPermission;
    } catch (err) {
      AccessControl.permission = null;
    }
  }

  isValidAccess(requiredPermissions: PermissionMap[]) {
    const { VUE_APP_ENABLED_ACCESS_PROFILE: enabledAccessProfile } = process.env;
    if (enabledAccessProfile !== 'YES') return true;
    const hasPermission = (name: PermissionMap) => AccessControl.permission && AccessControl.permission[name] === 'S';
    return requiredPermissions.every(hasPermission);
  }
}

export default new AccessControl();
